<template>
  <section class="about" v-if="!loading">
    <div class="about-content">
      <v-container>
        <SharedBreadcrumbs :items="items" />
        <v-row>
          <v-col cols="12" md="6">
            <h2 class="mb-4 mt-10">
              <span>
                {{ $t("overview") }}
              </span>
              <span class="text-primary">
                {{ $t("company") }}
              </span>
            </h2>
            <p class="mb-2">
              {{ aboutData.about?.about }}
            </p>
          </v-col>
          <v-col cols="12" md="6">
            <LazySharedImage
              class="w-100 rounded-xl mt-10"
              height="400px"
              :url="aboutData.about?.about_image"
            />
          </v-col>
        </v-row>
        <HomeAbout :items="aboutData.features" />
      </v-container>
    </div>
    <div class="white">
      <v-container>
        <div class="text-center">
          <h2>{{ $t("brands") }}</h2>
          <p class="color--gray">{{ $t("brands_description") }}</p>
        </div>
        <v-row class="mt-7 brands">
          <v-col
            class="brand"
            v-for="brand in aboutData.brands"
            :key="brand.id"
            cols="6"
            lg="3"
            md="4"
          >
            <div>
              <LazySharedImage class="w-100" height="100px" :url="brand.image" />
            </div>
          </v-col>
        </v-row>
      </v-container>
    </div>
  </section>
  <SharedPreloader v-else />
</template>
<script setup lang="js">
import { useI18n } from 'vue-i18n';
const { t } = useI18n();
const items = ref([
  {
    title: t('home'),
    disabled: false,
    href: "/",
  },
  {
    title: t('about'),
    disabled: true,
    href: "",
  },
]);

const aboutData=ref({});

const { get, loading } = useApi();
const getAbout = async ()=>{
  let response = await get("about");
  aboutData.value=response.data
}
onMounted(()=>{
  getAbout()
})
</script>
